@@ -1,5 +1,7 @@
 from .app import App
-import pybi.core.styles as styles
+
+# import pybi.core.styles as styles
+from pybi.core.styles import *
 from pybi.core import Sql
 
 # import pyvisflow.core.user_utils
