@@ -20,7 +20,12 @@ from pybi.core.components import (
 from pybi.core.components.reactiveComponent import EChart, Slicer, Table, TextValue
 from pybi.core.dataSource import DataSourceField, DataSourceTable, DataView
 from pybi.utils.dataSourceUtils import ds2sqlite_file_base64, ds2sqlite
-from pybi.utils.data_gen import json_dumps_fn, Jsonable, get_project_root
+from pybi.utils.data_gen import (
+    json_dumps_fn,
+    random_ds_name,
+    random_dv_name,
+    get_project_root,
+)
 from pybi.core.sql import Sql
 import pybi.utils.sql as sqlUtils
 
@@ -64,18 +69,22 @@ class App(ContainerComponent):
             return self._with_temp_host_stack[len(self._with_temp_host_stack) - 1]
         return None
 
-    def set_source(self, name: str, data: pd.DataFrame):
+    def set_source(self, data: pd.DataFrame, *, name: Optional[str] = None):
+        name = name or random_ds_name()
+
         ds = DataSource(name, data)
         self.dataSources.append(ds)
         return DataSourceTable(ds.name, data.columns.tolist())
 
     def set_dataView(
         self,
-        name: str,
         sql: str,
         exclude_source: Optional[List[DataSourceTable]] = None,
+        *,
+        name: Optional[str] = None,
     ):
         exclude_source = exclude_source or []
+        name = name or random_dv_name()
         dv = DataView(name, Sql(sql))
 
         for es in exclude_source:
